@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-gestures-extension.c,v 1.21 2005/01/28 22:30:05 chpe Exp $
+ *  $Id: ephy-gestures-extension.c,v 1.24 2005/10/24 16:12:56 philipl Exp $
  */
 
 #include "config.h"
@@ -29,18 +29,15 @@
 
 #include <epiphany/ephy-embed.h>
 #include <epiphany/ephy-tab.h>
-#include <epiphany/ephy-window.h>
 #include <epiphany/ephy-extension.h>
 
-#include <gtk/gtkaction.h>
-#include <gtk/gtkactiongroup.h>
-#include <gtk/gtkuimanager.h>
-
 #include <gmodule.h>
 #include <libxml/tree.h>
 
 #include <string.h>
 
+#define WINDOW_DATA_KEY	"EphyGesturesExtension::WindowData"
+
 #define EPHY_GESTURES_EXTENSION_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_GESTURES_EXTENSION, EphyGesturesExtensionPrivate))
 
 struct EphyGesturesExtensionPrivate
@@ -240,53 +237,38 @@ gesture_performed_cb (EphyGesture *gesture,
 		      const char *sequence,
 		      EphyGesturesExtension *extension)
 {
-	EphyWindow *window;
 	const char *path;
 
 	LOG ("Gesture: sequence '%s'", sequence);
 
 	path = g_hash_table_lookup (extension->priv->gestures, sequence);
-	if (path == NULL)
+	if (path)
 	{
-		return;
+		ephy_gesture_activate(gesture, path);
+	}
+}
+
+static EphyGesture *
+ensure_gesture (EphyGesturesExtension *extension,
+		EphyWindow *window)
+	        
+{
+	EphyGesture *gesture;
+
+	gesture = g_object_get_data (G_OBJECT (window), WINDOW_DATA_KEY);
+	if (gesture == NULL)
+	{
+		gesture = ephy_gesture_new (GTK_WIDGET (window));
+		g_signal_connect (gesture, "gesture-performed",
+				  G_CALLBACK (gesture_performed_cb),
+				  extension);
+
+		g_object_set_data_full (G_OBJECT (window), WINDOW_DATA_KEY,
+					gesture,
+					(GDestroyNotify) g_object_unref);
 	}
 
-	window = EPHY_WINDOW (ephy_gesture_get_window (gesture));
-	g_return_if_fail (EPHY_IS_WINDOW (window));
-
-	if (strcmp (path, "fallback") == 0)
-	{
-		/* Fall back to normal click */
-		EphyEmbed *embed;
-		EphyEmbedEvent *event;
-		gint handled = FALSE;
-
-		embed = ephy_window_get_active_embed (window);
-		g_return_if_fail (EPHY_IS_EMBED (embed));
-
-		event = ephy_gesture_get_event (gesture);
-		g_return_if_fail (EPHY_IS_EMBED_EVENT (event));
-
-		g_signal_emit_by_name (embed, "ge_dom_mouse_click", event,
-				       &handled);
-	}
-	else
-	{
-		GtkUIManager *manager;
-		GtkAction *action;
-		
-		manager = GTK_UI_MANAGER (ephy_window_get_ui_manager (window));
-		
-		action = gtk_ui_manager_get_action (manager, path);
-		
-		if (action == NULL)
-		{
-			g_warning ("Action for path '%s' not found!\n", path);
-			return;
-		}
-
-		gtk_action_activate (action);
-	}
+	return gesture;
 }
 
 static gboolean
@@ -297,27 +279,37 @@ dom_mouse_down_cb (EphyEmbed *embed,
         EphyEmbedEventContext context;
 	guint button;
 	gint handled = FALSE;
+	EphyTab *tab;
+	EphyWindow *window;
+	GtkWidget *toplevel;
+	gboolean ppv_mode;
+
+	tab = ephy_tab_for_embed (embed);
+	g_return_val_if_fail (EPHY_IS_TAB (tab), handled);
+		
+	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (tab));
+	g_return_val_if_fail (toplevel != NULL, handled);
+
+	/* disable gestures while print preview mode */
+	window = EPHY_WINDOW (toplevel);
+	g_return_val_if_fail (EPHY_IS_WINDOW (window), handled);
+
+	g_object_get (window, "print-preview-mode", &ppv_mode, NULL);
+	if (ppv_mode) return handled;
 
 	button = ephy_embed_event_get_button (event);
         context = ephy_embed_event_get_context (event);
 
-	if (button == 2 && !(context & EPHY_EMBED_CONTEXT_INPUT))
+	if (button == 2 &&
+	    !((context & EPHY_EMBED_CONTEXT_INPUT) ||
+	      (context & EPHY_EMBED_CONTEXT_LINK)))
 	{
 		EphyGesture *gesture;
-		GtkWidget *toplevel;
-		EphyTab *tab;
 
-		tab = ephy_tab_for_embed (embed);
-		g_return_val_if_fail (EPHY_IS_TAB (tab), handled);
+		gesture = ensure_gesture (extension, window);
+		g_return_val_if_fail (gesture != NULL, FALSE);
 
-		toplevel = gtk_widget_get_toplevel (GTK_WIDGET (tab));
-		g_return_val_if_fail (toplevel != NULL, handled);
-
-		gesture = ephy_gesture_new (toplevel, event);
-
-		g_signal_connect (gesture, "gesture-performed",
-				  G_CALLBACK (gesture_performed_cb),
-				  extension);
+		ephy_gesture_set_event (gesture, event);
 
 		ephy_gesture_start (gesture);
 
@@ -327,6 +319,13 @@ dom_mouse_down_cb (EphyEmbed *embed,
 	return handled;
 }
 
+static void
+impl_detach_window (EphyExtension *ext,
+                    EphyWindow *window)
+{
+        g_object_set_data (G_OBJECT (window), WINDOW_DATA_KEY, NULL);
+}
+
 static void
 impl_attach_tab (EphyExtension *extension,
 		 EphyWindow *window,
@@ -336,8 +335,6 @@ impl_attach_tab (EphyExtension *extension,
 
 	LOG ("Attach tab");
 
-	g_return_if_fail (EPHY_IS_TAB (tab));
-
 	embed = ephy_tab_get_embed (tab);
 	g_return_if_fail (EPHY_IS_EMBED (embed));
 
@@ -354,8 +351,6 @@ impl_detach_tab (EphyExtension *extension,
 
 	LOG ("Detach tab");
 
-	g_return_if_fail (EPHY_IS_TAB (tab));
-
 	embed = ephy_tab_get_embed (tab);
 	g_return_if_fail (EPHY_IS_EMBED (embed));
 
@@ -366,6 +361,7 @@ impl_detach_tab (EphyExtension *extension,
 static void
 ephy_gestures_extension_iface_init (EphyExtensionIface *iface)
 {
+	iface->detach_window = impl_detach_window;
 	iface->attach_tab = impl_attach_tab;
 	iface->detach_tab = impl_detach_tab;
 }
